@@ -2,7 +2,11 @@
 #include "stdlib.h"
 #include "string.h"
 
-#ifdef NEXT486
+#if defined NEXT486
+int kgetenv(char *env,  char *name){
+#elif defined PCLinux
+int kgetenv(char *env,  char *name){
+#elif defined IBMAIX
 int kgetenv(char *env,  char *name){
 #else
 int kgetenv_(char *env,  char *name){
@@ -11,7 +15,7 @@ int kgetenv_(char *env,  char *name){
 *                 must have NULL at the end.
 *     name: output. Environmental variable's value is put
 *                   must have enough length (NULL is not put)
-*     function value: length of the name not
+*     function value: length of the name.
 *     If env is not defnied.  0 is returned.
 *  The fortran routine must reset the string like
 *     integer leng
