@@ -22,7 +22,7 @@ c
       if(pj.charge .ne. 0) then
 c           k+-
          call ckChgDcy(pj, mupol, a, np, polari)
-      elseif(pj.subcode .eq. k0s) then
+      elseif(abs(pj.subcode) .eq. k0s) then
 c           k0 short
          call ckShortDecay(pj, a, np)
       else
@@ -127,6 +127,7 @@ c
       subroutine ckLongDecay(pj, mupol, a, np, polari)
       implicit none
 c----      include '../../Zptcl.h'
+
 #include  "Zptcl.h"
       logical mupol
       integer np
@@ -158,7 +159,7 @@ c           pi+ pi- pi0
       endif
       end
 c     ****************************************************
-      subroutine ckMuNeuPiDcy(pj,  a, np, polari)
+      subroutine ckMuNeuPiDcy(pj, a, np, polari)
 c     ****************************************************
 c       k->    mu + neum + pi (parent may be k charge,or k0)
 c              pi neglected       (set mu last)
@@ -188,15 +189,16 @@ c             k0l==> pi- mu+ nue(m) or  => pi+ mu- nue_b(m)
          call cmkptc(kmuon, 0, 1, a(2))
          jpa = 1
       else
+c           k0l; anti or regptcl
          call rndc(u)
          if(u .lt. 0.5) then
-            call cmkptc(kneumu, regptcl, 0, a(1))
-            call cmkptc(kmuon, 0, 1, a(2))
-            jpa = -1
-         else
             call cmkptc(kneumu, antip, 0, a(1))
             call cmkptc(kmuon, 0, -1, a(2))
             jpa = 1
+         else
+            call cmkptc(kneumu, regptcl, 0, a(1))
+            call cmkptc(kmuon, 0, 1, a(2))
+            jpa = -1
          endif
       endif
 c              sample energy of neum at rest of k
@@ -261,17 +263,15 @@ c             k0l==> pi- mu+ nue(m) or => pi+ mu- nue_b(m)
             call cmkptc(kpion, 0, 0, a(2))
             call cmkptc(kmuon, 0, -1, a(3))
          else
-            if(pj.subcode .eq. k0l) then
-               call rndc(u)
-               if(u .lt. 0.5) then
-                  call cmkptc(kneumu, antip, 0, a(1))
-                  call cmkptc(kpion, 0, 1, a(2))
-                  call cmkptc(kmuon, 0, -1, a(3))
-               else
-                  call cmkptc(kneumu, regptcl, 0, a(1))
-                  call cmkptc(kpion, 0, -1, a(2))
-                  call cmkptc(kmuon, 0, 1, a(3))
-               endif
+            call rndc(u)
+            if(u .lt. 0.5) then
+               call cmkptc(kneumu, antip, 0, a(1))
+               call cmkptc(kpion, 0, 1, a(2))
+               call cmkptc(kmuon, 0, -1, a(3))
+            else
+               call cmkptc(kneumu, regptcl, 0, a(1))
+               call cmkptc(kpion, 0, -1, a(2))
+               call cmkptc(kmuon, 0, 1, a(3))
             endif
          endif
          np=3
@@ -297,7 +297,8 @@ c----      include '../../Zcode.h'
       record /ptcl/ pj, a(*)
 
       real*8 u, f, ecm, cosa
-c
+      integer i
+
 c        make electron neu
       if(pj.charge .eq. -1.) then
          call cmkptc(kneue, antip, 0, a(1))
@@ -306,9 +307,9 @@ c        make electron neu
       else
          call rndc(u)
          if(u .lt. 0.5) then
-            call cmkptc(kneue, regptcl, 0, a(1))
-         else
             call cmkptc(kneue, antip,  0, a(1))
+         else
+            call cmkptc(kneue, regptcl, 0, a(1))
          endif
       endif
 c              sample energy of neue at rest of k
@@ -321,6 +322,11 @@ c          set px,py,pz
       call cpCos2pxyz(cosa, ecm, a(1).fm)
       a(1).fm.p(4) = ecm
       np=1
+c              boost to lab
+      do i = 1, np
+         call cibst1(i, pj, a(i), a(i))
+      enddo
+
       end
 c    ******************************************************************
 c    *   ckMuDecay:   k -> mu + neumu
