@@ -9,10 +9,15 @@ c	(->	------------------------------------
 	character*70  ContFile     !1  Job continuation information file  (full or relative path).
                                    !   default is "ContInfo".  This will be created when job
                                    !   is finished normally.
+	character*70  GeomagFile   !2  IGRF or WMM file path which contains geomagnetic field expansion 
+                                   !   coefficients.  Their format is the same one as given in their web 
+                                   !   page.  If ' ' (default), Cosmos/Data/Geomag/igrf is used.
 	character*70  SkeletonFile !1   Skeleton information file (full or relative path). created if Job =
                                    !    'skeleton'. Default is 'skeletonParam'.  This is the Namelist data
                                    !     referred by Cosmos automatically  if Job='flesh' is specified. For
                                    !     Job='flesh', you have to modify some part of  this file.
+        character*70  DpmFile      !2  control card to specify the dpmjet execution conditions. If ' ',
+	                           !   Cosmos/Data/DPM/atmos.inp is assumed.  
 	character*10  Job          !1  What kind of job you are going to do.\newline
                                    !   =' ' (default).  nothing special.\newline
                                    !   ='skeleton'.  Makes skeleton. Later you can add AS, follow particles
@@ -31,7 +36,10 @@ c	(->	------------------------------------
                                    !      and the event number are  automatically output on the speicfied disk file.
         integer       SeedFileDev  !2   logical device number of SeedFile.
 	logical       Cont         !1  If T, continuation from a previous job is assumed. Contfile content is used.
-	integer       InitRN       !1  Initial random number seed. 2 integers.
+	integer       InitRN       !1  Initial random number seed. 2 integers. If InitRN(1) < 0, file dev #14 is
+                                   ! assumed to have  pairs of IR in each row, and they are read to initialize
+                                   ! each event.  This is not enabled when Job = 'flesh'. The #14 file should be
+                                   ! opened by the user routine   (chookBgRun). This is almost debug purpose.
 	integer       EventNo      !2  cumulative event number counter.(excluding discarded ones due to cutoff).
 	integer       EventsInTheRun !2  Counter for event number in the run. Internal use.
                                      !          (excluding discarded ones due to cutoff).
@@ -68,7 +76,7 @@ c	<-)	-------------------------------------
      *  PrevEventNo, SeedFileDev, EventNo
 
 
-	common /Zmanagerpc2/ UserHookc(MAX_USERHOOKC), PrimaryFile,
-     *  CutOffFile,  Job, ContFile, AtmosFile,
-     *  SkeletonFile, SeedFile, DeadLine
-
+       common /Zmanagerpc2/
+     * UserHookc(MAX_USERHOOKC), PrimaryFile,
+     * CutOffFile,  Job, ContFile, AtmosFile, GeomagFile,
+     * SkeletonFile, SeedFile, DpmFile, DeadLine
