@@ -81,9 +81,9 @@ c -------------------------------------tracking a ptcl
 c                next is for DEBUG
 c//////
 c      logical deb
-c      common /cccdeb/ deb
+c      common /cdebug/ deb
 c/////////
-ccc   c#define DEBUG 1
+ccc c#define DEBUG 1
 
 
 
@@ -305,7 +305,7 @@ c         MovedTrack.t = 0.     ! bug bef uv6.09
 #include  "Zobsv.h"
 
       logical deb
-      common /cccdeb/deb
+      common /cdebug/deb
 
       character*(*) str
       integer i
@@ -313,16 +313,8 @@ c         MovedTrack.t = 0.     ! bug bef uv6.09
       data nc/0/
       nc = nc + 1
 c      if(nc .gt. 750) then
-      if( MovedTrack.p.code .eq. 4 .and. 
-     *      MovedTrack.p.charge .eq. 1 .and.
-     *      abs(MovedTrack.p.fm.p(4)-127.939) .le. 1.d-2) then
-         deb =.true.
+      if( deb) then
 
-c         if(TrackBefMove.p.code .eq. 6
-c     *     .and. 
-c     *   abs(TrackBefMove.p.fm.p(4)- 14077.514663).lt. 1.d-6) then
-c
-c            deb = .true.
 
             write(*,*) str, ' code=',TrackBefMove.p.code,
      *         ' cg',TrackBefMove.p.charge,
